@@ -58,21 +58,23 @@ class Image(Media):
 
 
 
-    def to_json(self, key_name: str) -> str:
+    def to_json(self, key_name: str, is_list=False, index=0) -> str:
         assert_that(key_name).is_not_none()
 
-        return json.dumps({
+        return json.dumps(self.to_dict(key_name, is_list, index))
+
+    def to_dict(self, key_name: str, is_list=False, index=0):
+        return {
             "log_type": self.log_type,
             "hash": self.get_digest(),
             "size": self.get_size(),
-            "path": self.get_path(key_name),
+            "path": self.get_path(key_name, is_list, index),
             "height": self.height,
             "width": self.width,
             "format": self.format,
             "caption": self.caption if self.caption else "",
             "boxes": self.boxes.to_dict() if self.boxes else "",
-
-        })
+        }
 
     def get_size(self) -> int:
         return os.stat(self.local_path).st_size
@@ -96,9 +98,12 @@ class Image(Media):
                               artifact_name="", artifact_type="", artifact_digest="", entry_digest=digest,
                               entry_list=[], file_index=0)
 
-    def get_path(self, key_name: str) -> str:
-        # server 패스
-        return f"{key_name}.IMAGE.{self.format}"
+    def get_path(self, key_name: str, is_list=False, index=0) -> str:
+        if is_list:
+            return f"{key_name}.IMAGE.{index}.{self.format}"
+        else:
+            # server 패스
+            return f"{key_name}.IMAGE.{self.format}"
 
     def get_root_path(self, run_id: int) -> str:
         return os.path.join(str(run_id), "media")
