@@ -1,8 +1,12 @@
 from __future__ import annotations
 
+import json
 import time
 from assertpy import assert_that
 from typing import Dict, Tuple, TYPE_CHECKING
+
+
+
 from deepdriver import logger
 from deepdriver.sdk import util
 from deepdriver.sdk.interface import interface
@@ -65,6 +69,14 @@ class Run:
                 data[key] = value.to_json(key)
                 logger.debug(f"Chart를 str(json)로 변환 변환 : {data[key]}")
                 value.upload_file(self, key)
+            elif isinstance(value, list):
+                if all(isinstance(n, Image) for n in value):    #Image 객체 배열일 경우
+                        data[key] = json.dumps([n.to_dict(key_name=key, is_list=True, index=index) for index, n in enumerate(value) ])
+                        for n in value:
+                            n.upload_file(self, key)
+                        logger.debug(f"Image 객체(배열)을 str(json)로 변환 변환 : {data[key]}")
+
+
 
 
         data["timestamp"] = time.time()
